.. include:: globals.rst
.. _permissions:

===========
Permissions
===========

.. contents::
    :local:


.. _adminactions_export:

adminactions_export
===================

Permission required to execute :ref:`export_as_csv`, :ref:`export_as_xls`, :ref:`export_as_fixture`,
:ref:`export_delete_tree`



.. _adminactions_massupdate:

adminactions_massupdate
=======================

Required to execute :ref:`massupdate`


.. _adminactions_merge:


adminactions_merge
==================

Required to execute :ref:`merge`

